@@ -1,5 +1,8 @@
+from pyworkflow.utils import weakImport
 
 from .protocol_cryolo_training import SphireProtCRYOLOTraining
 from .protocol_cryolo_picking import SphireProtCRYOLOPicking
 from .protocol_cryolo_import import SphireProtCryoloImport
 from .protocol_janni_denoise import SphireProtJanniDenoising
+with weakImport('tomo'):
+    from .protocol_cryolo_tomo_picking import SphireProtCRYOLOTomoPicking
